======
Series
======

This page gives an overview of all public Series methods.

.. toctree::
   :maxdepth: 2
   :hidden:

   aggregation
   array
   attributes
   binary
   boolean
   categories
   computation
   descriptive
   export
   list
   modify_select
   miscellaneous
   operators
   plot
   string
   struct
   temporal

.. _series:

.. currentmodule:: polars

.. autoclass:: Series
    :members:
    :noindex:
    :autosummary:
    :autosummary-nosignatures:
